@@ -1,16 +1,15 @@
 from itertools import chain
 from typing import Any, Dict, Iterable, List, Mapping, Optional
 
-import requests.exceptions
-from gql import Client, gql
-from gql.transport import Transport
-from gql.transport.requests import RequestsHTTPTransport
-
 import dagster._check as check
+import requests.exceptions
 from dagster import DagsterRunStatus
 from dagster._annotations import public
 from dagster._core.definitions.utils import validate_tags
 from dagster._utils.backcompat import experimental_class_warning
+from gql import Client, gql
+from gql.transport import Transport
+from gql.transport.requests import RequestsHTTPTransport
 
 from .client_queries import (
     CLIENT_GET_REPO_LOCATIONS_NAMES_AND_PIPELINES_QUERY,
@@ -32,7 +31,7 @@ from .utils import (
 
 
 class DagsterGraphQLClient:
-    """Official Dagster Python Client for GraphQL
+    """Official Dagster Python Client for GraphQL.
 
     Utilizes the gql library to dispatch queries over HTTP to a remote Dagster GraphQL Server
 
@@ -99,7 +98,8 @@ class DagsterGraphQLClient:
             return self._client.execute(gql(query), variable_values=variables)
         except Exception as exc:  # catch generic Exception from the gql client
             raise DagsterGraphQLClientError(
-                f"Exception occured during execution of query \n{query}\n with variables \n{variables}\n"
+                f"Exception occured during execution of query \n{query}\n with variables"
+                f" \n{variables}\n"
             ) from exc
 
     def _get_repo_locations_and_names_with_pipeline(self, pipeline_name: str) -> List[PipelineInfo]:
@@ -136,8 +136,10 @@ class DagsterGraphQLClient:
         # The following invariant will never fail when a job is executed
         check.invariant(
             (mode is not None and run_config is not None) or preset is not None,
-            "Either a mode and run_config or a preset must be specified in order to "
-            f"submit the pipeline {pipeline_name} for execution",
+            (
+                "Either a mode and run_config or a preset must be specified in order to "
+                f"submit the pipeline {pipeline_name} for execution"
+            ),
         )
         tags = validate_tags(tags)
 
@@ -148,7 +150,10 @@ class DagsterGraphQLClient:
             if len(pipeline_info_lst) == 0:
                 raise DagsterGraphQLClientError(
                     f"{pipeline_or_job}NotFoundError",
-                    f"No {'jobs' if is_using_job_op_graph_apis else 'pipelines'} with the name `{pipeline_name}` exist",
+                    (
+                        f"No {'jobs' if is_using_job_op_graph_apis else 'pipelines'} with the name"
+                        f" `{pipeline_name}` exist"
+                    ),
                 )
             elif len(pipeline_info_lst) == 1:
                 pipeline_info = pipeline_info_lst[0]
@@ -156,9 +161,9 @@ class DagsterGraphQLClient:
                 repository_name = pipeline_info.repository_name
             else:
                 raise DagsterGraphQLClientError(
-                    "Must specify repository_location_name and repository_name"
-                    f" since there are multiple {'jobs' if is_using_job_op_graph_apis else 'pipelines'} with the name {pipeline_name}."
-                    f"\n\tchoose one of: {pipeline_info_lst}"
+                    "Must specify repository_location_name and repository_name since there are"
+                    f" multiple {'jobs' if is_using_job_op_graph_apis else 'pipelines'} with the"
+                    f" name {pipeline_name}.\n\tchoose one of: {pipeline_info_lst}"
                 )
 
         variables: Dict[str, Any] = {
@@ -325,7 +330,7 @@ class DagsterGraphQLClient:
 
     @public
     def get_run_status(self, run_id: str) -> DagsterRunStatus:
-        """Get the status of a given Pipeline Run
+        """Get the status of a given Pipeline Run.
 
         Args:
             run_id (str): run id of the requested pipeline run.
