@@ -9,7 +9,7 @@ class DagsterGraphQLClientError(Exception):
 
 
 class ReloadRepositoryLocationStatus(Enum):
-    """This enum describes the status of a GraphQL mutation to reload a Dagster repository location
+    """This enum describes the status of a GraphQL mutation to reload a Dagster repository location.
 
     Args:
         Enum (str): can be either `ReloadRepositoryLocationStatus.SUCCESS`
@@ -20,6 +20,11 @@ class ReloadRepositoryLocationStatus(Enum):
     FAILURE = "FAILURE"
 
 
+class ShutdownRepositoryLocationStatus(Enum):
+    SUCCESS = "SUCCESS"
+    FAILURE = "FAILURE"
+
+
 class ReloadRepositoryLocationInfo(NamedTuple):
     """This class gives information about the result of reloading
     a Dagster repository location with a GraphQL mutation.
@@ -37,6 +42,20 @@ class ReloadRepositoryLocationInfo(NamedTuple):
     message: Optional[str] = None
 
 
+class ShutdownRepositoryLocationInfo(NamedTuple):
+    """This class gives information about the result of shutting down the server for
+    a Dagster repository location using a GraphQL mutation.
+
+    Args:
+        status (ShutdownRepositoryLocationStatus) Whether the shutdown succeeded or failed.
+        message (Optional[str], optional): the failure message/reason if
+          `status == ShutdownRepositoryLocationStatus.FAILURE`. Defaults to None.
+    """
+
+    status: ShutdownRepositoryLocationStatus
+    message: Optional[str] = None
+
+
 class PipelineInfo(NamedTuple):
     repository_location_name: str
     repository_name: str
