@@ -1,5 +1,5 @@
 from math import isnan
-from typing import Any, Iterator, Sequence, no_type_check
+from typing import Any, Iterator, Sequence, Union, cast, no_type_check
 
 import dagster._check as check
 import dagster._seven as seven
@@ -20,18 +20,24 @@ from dagster import (
     TextMetadataValue,
     UrlMetadataValue,
 )
-from dagster._core.events import DagsterEventType
+from dagster._core.definitions.metadata import DagsterRunMetadataValue, PartitionMetadataEntry
+from dagster._core.events import (
+    DagsterEventType,
+    HandledOutputData,
+    LoadedInputData,
+    StepExpectationResultData,
+)
 from dagster._core.events.log import EventLogEntry
-from dagster._core.execution.plan.objects import StepFailureData
-from dagster._legacy import DagsterPipelineRunMetadataValue
+from dagster._core.execution.plan.inputs import StepInputData
+from dagster._core.execution.plan.outputs import StepOutputData
 
 MAX_INT = 2147483647
 MIN_INT = -2147483648
 
 
-def iterate_metadata_entries(metadata_entries: Sequence[MetadataEntry]) -> Iterator[Any]:
-    from dagster_graphql.schema.table import GrapheneTable, GrapheneTableSchema
-
+def iterate_metadata_entries(
+    metadata_entries: Sequence[Union[MetadataEntry, PartitionMetadataEntry]]
+) -> Iterator[Any]:
     from ..schema.metadata import (
         GrapheneAssetMetadataEntry,
         GrapheneBoolMetadataEntry,
@@ -49,9 +55,11 @@ def iterate_metadata_entries(metadata_entries: Sequence[MetadataEntry]) -> Itera
         GrapheneTextMetadataEntry,
         GrapheneUrlMetadataEntry,
     )
+    from ..schema.table import GrapheneTable, GrapheneTableSchema
 
     check.sequence_param(metadata_entries, "metadata_entries", of_type=MetadataEntry)
     for metadata_entry in metadata_entries:
+        metadata_entry = cast(MetadataEntry, metadata_entry)
         if isinstance(metadata_entry.entry_data, PathMetadataValue):
             yield GraphenePathMetadataEntry(
                 label=metadata_entry.label,
@@ -134,7 +142,7 @@ def iterate_metadata_entries(metadata_entries: Sequence[MetadataEntry]) -> Itera
                 label=metadata_entry.label,
                 description=metadata_entry.description,
             )
-        elif isinstance(metadata_entry.entry_data, DagsterPipelineRunMetadataValue):
+        elif isinstance(metadata_entry.entry_data, DagsterRunMetadataValue):
             yield GraphenePipelineRunMetadataEntry(
                 label=metadata_entry.label,
                 description=metadata_entry.description,
@@ -245,23 +253,23 @@ def from_dagster_event_record(event_record: EventLogEntry, pipeline_name: str) -
     elif dagster_event.event_type == DagsterEventType.STEP_SUCCESS:
         return GrapheneExecutionStepSuccessEvent(**basic_params)
     elif dagster_event.event_type == DagsterEventType.STEP_INPUT:
-        input_data = check.not_none(dagster_event.event_specific_data)
+        data = cast(StepInputData, dagster_event.event_specific_data)
         return GrapheneExecutionStepInputEvent(
-            input_name=input_data.input_name,
-            type_check=input_data.type_check_data,
+            input_name=data.input_name,
+            type_check=data.type_check_data,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.STEP_OUTPUT:
-        output_data = dagster_event.step_output_data
+        data = cast(StepOutputData, dagster_event.event_specific_data)
         return GrapheneExecutionStepOutputEvent(
-            output_name=output_data.output_name,
-            type_check=output_data.type_check_data,
-            metadataEntries=_to_metadata_entries(output_data.metadata_entries),
+            output_name=data.output_name,
+            type_check=data.type_check_data,
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.ASSET_MATERIALIZATION:
-        asset_lineage = dagster_event.step_materialization_data.asset_lineage
-        return GrapheneMaterializationEvent(event=event_record, assetLineage=asset_lineage)
+        data = dagster_event.step_materialization_data
+        return GrapheneMaterializationEvent(event=event_record, assetLineage=data.asset_lineage)
     elif dagster_event.event_type == DagsterEventType.ASSET_OBSERVATION:
         return GrapheneObservationEvent(
             event=event_record,
@@ -269,20 +277,16 @@ def from_dagster_event_record(event_record: EventLogEntry, pipeline_name: str) -
     elif dagster_event.event_type == DagsterEventType.ASSET_MATERIALIZATION_PLANNED:
         return GrapheneAssetMaterializationPlannedEvent(event=event_record)
     elif dagster_event.event_type == DagsterEventType.STEP_EXPECTATION_RESULT:
-        expectation_result = dagster_event.event_specific_data.expectation_result
+        data = cast(StepExpectationResultData, dagster_event.event_specific_data)
         return GrapheneStepExpectationResultEvent(
-            expectation_result=expectation_result, **basic_params
+            expectation_result=data.expectation_result, **basic_params
         )
     elif dagster_event.event_type == DagsterEventType.STEP_FAILURE:
-        check.inst(dagster_event.step_failure_data, StepFailureData)
+        data = dagster_event.step_failure_data
         return GrapheneExecutionStepFailureEvent(
-            error=(
-                GraphenePythonError(dagster_event.step_failure_data.error)
-                if dagster_event.step_failure_data.error
-                else None
-            ),
-            failureMetadata=dagster_event.step_failure_data.user_failure_data,
-            errorSource=dagster_event.step_failure_data.error_source,
+            error=(GraphenePythonError(data.error) if data.error else None),
+            failureMetadata=data.user_failure_data,
+            errorSource=data.error_source,
             **basic_params,
         )
 
@@ -325,11 +329,10 @@ def from_dagster_event_record(event_record: EventLogEntry, pipeline_name: str) -
         DagsterEventType.RUN_FAILURE,
         DagsterEventType.PIPELINE_FAILURE,
     ):
+        data = dagster_event.pipeline_failure_data
         return GrapheneRunFailureEvent(
             pipelineName=pipeline_name,
-            error=GraphenePythonError(dagster_event.pipeline_failure_data.error)
-            if (dagster_event.pipeline_failure_data and dagster_event.pipeline_failure_data.error)
-            else None,
+            error=GraphenePythonError(data.error) if (data and data.error) else None,
             **basic_params,
         )
 
@@ -340,36 +343,37 @@ def from_dagster_event_record(event_record: EventLogEntry, pipeline_name: str) -
     elif dagster_event.event_type == DagsterEventType.ALERT_FAILURE:
         return GrapheneAlertFailureEvent(pipelineName=pipeline_name, **basic_params)
     elif dagster_event.event_type == DagsterEventType.HANDLED_OUTPUT:
+        data = cast(HandledOutputData, dagster_event.event_specific_data)
         return GrapheneHandledOutputEvent(
-            output_name=dagster_event.event_specific_data.output_name,
-            manager_key=dagster_event.event_specific_data.manager_key,
+            output_name=data.output_name,
+            manager_key=data.manager_key,
             metadataEntries=_to_metadata_entries(
                 dagster_event.event_specific_data.metadata_entries  # type: ignore
             ),
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.LOADED_INPUT:
+        data = cast(LoadedInputData, dagster_event.event_specific_data)
         return GrapheneLoadedInputEvent(
-            input_name=dagster_event.event_specific_data.input_name,
-            manager_key=dagster_event.event_specific_data.manager_key,
-            upstream_output_name=dagster_event.event_specific_data.upstream_output_name,
-            upstream_step_key=dagster_event.event_specific_data.upstream_step_key,
-            metadataEntries=_to_metadata_entries(
-                dagster_event.event_specific_data.metadata_entries  # type: ignore
-            ),
+            input_name=data.input_name,
+            manager_key=data.manager_key,
+            upstream_output_name=data.upstream_output_name,
+            upstream_step_key=data.upstream_step_key,
+            metadataEntries=_to_metadata_entries(data.metadata_entries or []),
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.OBJECT_STORE_OPERATION:
-        operation_result = dagster_event.event_specific_data
-        return GrapheneObjectStoreOperationEvent(operation_result=operation_result, **basic_params)
+        data = dagster_event.event_specific_data
+        return GrapheneObjectStoreOperationEvent(operation_result=data, **basic_params)
     elif dagster_event.event_type == DagsterEventType.ENGINE_EVENT:
+        data = dagster_event.engine_event_data
         return GrapheneEngineEvent(
-            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
-            error=GraphenePythonError(dagster_event.engine_event_data.error)
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
+            error=GraphenePythonError(data.error)
             if dagster_event.engine_event_data.error
             else None,
-            markerStart=dagster_event.engine_event_data.marker_start,
-            markerEnd=dagster_event.engine_event_data.marker_end,
+            markerStart=data.marker_start,
+            markerEnd=data.marker_end,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.HOOK_COMPLETED:
@@ -377,61 +381,64 @@ def from_dagster_event_record(event_record: EventLogEntry, pipeline_name: str) -
     elif dagster_event.event_type == DagsterEventType.HOOK_SKIPPED:
         return GrapheneHookSkippedEvent(**basic_params)
     elif dagster_event.event_type == DagsterEventType.HOOK_ERRORED:
+        data = dagster_event.hook_errored_data
         return GrapheneHookErroredEvent(
-            error=GraphenePythonError(dagster_event.hook_errored_data.error),
+            error=GraphenePythonError(data.error),
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.LOGS_CAPTURED:
+        data = dagster_event.logs_captured_data
         return GrapheneLogsCapturedEvent(
-            fileKey=dagster_event.logs_captured_data.file_key,
-            logKey=dagster_event.logs_captured_data.file_key,
-            stepKeys=dagster_event.logs_captured_data.step_keys,
-            externalUrl=dagster_event.logs_captured_data.external_url,
+            fileKey=data.file_key,
+            logKey=data.file_key,
+            stepKeys=data.step_keys,
+            externalUrl=data.external_url,
             pid=dagster_event.pid,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.STEP_WORKER_STARTING:
+        data = dagster_event.engine_event_data
         return GrapheneStepWorkerStartingEvent(
-            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
-            markerStart=dagster_event.engine_event_data.marker_start,
-            markerEnd=dagster_event.engine_event_data.marker_end,
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
+            markerStart=data.marker_start,
+            markerEnd=data.marker_end,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.STEP_WORKER_STARTED:
+        data = dagster_event.engine_event_data
         return GrapheneStepWorkerStartedEvent(
-            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
-            markerStart=dagster_event.engine_event_data.marker_start,
-            markerEnd=dagster_event.engine_event_data.marker_end,
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
+            markerStart=data.marker_start,
+            markerEnd=data.marker_end,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.RESOURCE_INIT_STARTED:
+        data = dagster_event.engine_event_data
         return GrapheneResourceInitStartedEvent(
-            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
-            markerStart=dagster_event.engine_event_data.marker_start,
-            markerEnd=dagster_event.engine_event_data.marker_end,
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
+            markerStart=data.marker_start,
+            markerEnd=data.marker_end,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.RESOURCE_INIT_SUCCESS:
+        data = dagster_event.engine_event_data
         return GrapheneResourceInitSuccessEvent(
-            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
-            markerStart=dagster_event.engine_event_data.marker_start,
-            markerEnd=dagster_event.engine_event_data.marker_end,
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
+            markerStart=data.marker_start,
+            markerEnd=data.marker_end,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.RESOURCE_INIT_FAILURE:
+        data = dagster_event.engine_event_data
         return GrapheneResourceInitFailureEvent(
-            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
-            markerStart=dagster_event.engine_event_data.marker_start,
-            markerEnd=dagster_event.engine_event_data.marker_end,
-            error=GraphenePythonError(dagster_event.engine_event_data.error),
+            metadataEntries=_to_metadata_entries(data.metadata_entries),
+            markerStart=data.marker_start,
+            markerEnd=data.marker_end,
+            error=GraphenePythonError(data.error),
             **basic_params,
         )
     else:
-        raise Exception(
-            "Unknown DAGSTER_EVENT type {inner_type} found in logs".format(
-                inner_type=dagster_event.event_type
-            )
-        )
+        raise Exception(f"Unknown DAGSTER_EVENT type {dagster_event.event_type} found in logs")
 
 
 def from_event_record(event_record: EventLogEntry, pipeline_name: str) -> Any:
