@@ -1,5 +1,8 @@
+from typing import cast
+
 import dagster._check as check
 import graphene
+from dagster import MultiPartitionsDefinition
 from dagster._core.host_representation import ExternalPartitionSet, RepositoryHandle
 from dagster._core.host_representation.external_data import (
     ExternalMultiPartitionsDefinitionData,
@@ -32,7 +35,7 @@ from .pipelines.pipeline import GrapheneRun
 from .pipelines.status import GrapheneRunStatus
 from .repository_origin import GrapheneRepositoryOrigin
 from .tags import GraphenePipelineTag
-from .util import non_null_list
+from .util import ResolveInfo, non_null_list
 
 
 class GraphenePartitionTags(graphene.ObjectType):
@@ -136,7 +139,7 @@ class GraphenePartition(graphene.ObjectType):
             mode=external_partition_set.mode,
         )
 
-    def resolve_runConfigOrError(self, graphene_info):
+    def resolve_runConfigOrError(self, graphene_info: ResolveInfo):
         return get_partition_config(
             graphene_info,
             self._external_repository_handle,
@@ -144,7 +147,7 @@ class GraphenePartition(graphene.ObjectType):
             self._partition_name,
         )
 
-    def resolve_tagsOrError(self, graphene_info):
+    def resolve_tagsOrError(self, graphene_info: ResolveInfo):
         return get_partition_tags(
             graphene_info,
             self._external_repository_handle,
@@ -152,7 +155,7 @@ class GraphenePartition(graphene.ObjectType):
             self._partition_name,
         )
 
-    def resolve_runs(self, graphene_info, **kwargs):
+    def resolve_runs(self, graphene_info: ResolveInfo, **kwargs):
         filters = kwargs.get("filter")
         partition_tags = {
             PARTITION_SET_TAG: self._external_partition_set.name,
@@ -227,20 +230,20 @@ class GraphenePartitionSet(graphene.ObjectType):
             mode=external_partition_set.mode,
         )
 
-    def resolve_id(self, _graphene_info):
+    def resolve_id(self, _graphene_info: ResolveInfo):
         return self._external_partition_set.get_external_origin_id()
 
-    def resolve_partitionsOrError(self, graphene_info, **kwargs):
+    def resolve_partitionsOrError(self, graphene_info: ResolveInfo, **kwargs):
         return get_partitions(
             graphene_info,
             self._external_repository_handle,
             self._external_partition_set,
             cursor=kwargs.get("cursor"),
             limit=kwargs.get("limit"),
-            reverse=kwargs.get("reverse"),
+            reverse=kwargs.get("reverse") or False,
         )
 
-    def resolve_partition(self, graphene_info, partition_name):
+    def resolve_partition(self, graphene_info: ResolveInfo, partition_name):
         return get_partition_by_name(
             graphene_info,
             self._external_repository_handle,
@@ -248,10 +251,10 @@ class GraphenePartitionSet(graphene.ObjectType):
             partition_name,
         )
 
-    def resolve_partitionRuns(self, graphene_info):
+    def resolve_partitionRuns(self, graphene_info: ResolveInfo):
         return get_partition_set_partition_runs(graphene_info, self._external_partition_set)
 
-    def resolve_partitionStatusesOrError(self, graphene_info):
+    def resolve_partitionStatusesOrError(self, graphene_info: ResolveInfo):
         return get_partition_set_partition_statuses(
             graphene_info,
             self._external_partition_set,
@@ -261,7 +264,7 @@ class GraphenePartitionSet(graphene.ObjectType):
         origin = self._external_partition_set.get_external_origin().external_repository_origin
         return GrapheneRepositoryOrigin(origin)
 
-    def resolve_backfills(self, graphene_info, **kwargs):
+    def resolve_backfills(self, graphene_info: ResolveInfo, **kwargs):
         matching = [
             backfill
             for backfill in graphene_info.context.instance.get_backfills(
@@ -322,20 +325,45 @@ class GrapheneDimensionDefinitionType(graphene.ObjectType):
     name = graphene.NonNull(graphene.String)
     description = graphene.NonNull(graphene.String)
     type = graphene.NonNull(GraphenePartitionDefinitionType)
+    isPrimaryDimension = graphene.NonNull(graphene.Boolean)
 
     class Meta:
         name = "DimensionDefinitionType"
 
 
+class GrapheneTimePartitionsDefinitionMetadata(graphene.ObjectType):
+    startTime = graphene.NonNull(graphene.Float)
+    endTime = graphene.NonNull(graphene.Float)
+    startKey = graphene.NonNull(graphene.String)
+    endKey = graphene.NonNull(graphene.String)
+
+    class Meta:
+        name = "TimePartitionsDefinitionMetadata"
+
+
 class GraphenePartitionDefinition(graphene.ObjectType):
     description = graphene.NonNull(graphene.String)
     type = graphene.NonNull(GraphenePartitionDefinitionType)
     dimensionTypes = non_null_list(GrapheneDimensionDefinitionType)
+    timeWindowMetadata = graphene.Field(GrapheneTimePartitionsDefinitionMetadata)
 
     class Meta:
         name = "PartitionDefinition"
 
     def __init__(self, partition_def_data: ExternalPartitionsDefinitionData):
+        def _get_time_partitions_metadata(partition_def_data):
+            check.inst_param(
+                partition_def_data, "partition_def_data", ExternalTimeWindowPartitionsDefinitionData
+            )
+
+            partitions_def = partition_def_data.get_partitions_definition()
+            return GrapheneTimePartitionsDefinitionMetadata(
+                startTime=partitions_def.start.timestamp(),
+                endTime=partitions_def.get_current_timestamp(),
+                startKey=partitions_def.get_first_partition_key(),
+                endKey=partitions_def.get_last_partition_key(),
+            )
+
         super().__init__(
             description=str(partition_def_data.get_partitions_definition()),
             type=GraphenePartitionDefinitionType.from_partition_def_data(partition_def_data),
@@ -346,6 +374,10 @@ class GraphenePartitionDefinition(graphene.ObjectType):
                     type=GraphenePartitionDefinitionType.from_partition_def_data(
                         dim.external_partitions_def_data
                     ),
+                    isPrimaryDimension=dim.name
+                    == cast(
+                        MultiPartitionsDefinition, partition_def_data.get_partitions_definition()
+                    ).primary_dimension.name,
                 )
                 for dim in partition_def_data.external_partition_dimension_definitions
             ]
@@ -357,8 +389,12 @@ class GraphenePartitionDefinition(graphene.ObjectType):
                     type=GraphenePartitionDefinitionType.from_partition_def_data(
                         partition_def_data
                     ),
+                    isPrimaryDimension=True,
                 )
             ],
+            timeWindowMetadata=_get_time_partitions_metadata(partition_def_data)
+            if isinstance(partition_def_data, ExternalTimeWindowPartitionsDefinitionData)
+            else None,
         )
 
 
