@@ -1,14 +1,14 @@
 import asyncio
 from contextlib import contextmanager
 
-from dagster_graphql.schema import create_schema
-
 import dagster._check as check
 from dagster._core.instance import DagsterInstance
 from dagster._core.test_utils import wait_for_runs_to_finish
 from dagster._core.workspace.context import WorkspaceProcessContext
 from dagster._core.workspace.load_target import PythonFileTarget
 
+from dagster_graphql.schema import create_schema
+
 
 def main_repo_location_name():
     return "test_location"
@@ -70,16 +70,16 @@ def execute_dagster_graphql_and_finish_runs(context, query, variables=None):
 
 
 @contextmanager
-def define_out_of_process_context(python_file, fn_name, instance):
+def define_out_of_process_context(python_file, fn_name, instance, read_only=False):
     check.inst_param(instance, "instance", DagsterInstance)
 
     with define_out_of_process_workspace(
-        python_file, fn_name, instance
+        python_file, fn_name, instance, read_only=read_only
     ) as workspace_process_context:
         yield workspace_process_context.create_request_context()
 
 
-def define_out_of_process_workspace(python_file, fn_name, instance):
+def define_out_of_process_workspace(python_file, fn_name, instance, read_only=False):
     return WorkspaceProcessContext(
         instance,
         PythonFileTarget(
@@ -89,6 +89,7 @@ def define_out_of_process_workspace(python_file, fn_name, instance):
             location_name=main_repo_location_name(),
         ),
         version="",
+        read_only=read_only,
     )
 
 
